@@ -604,10 +604,10 @@ def setLocusOfFocus(event, obj, notifyScript=True, force=False):
         currentApp = orca_state.activeScript.app
         try:
             appList = [event.host_application, event.source.getApplication()]
-        except LookupError:
+        except (LookupError, RuntimeError):
             appList = []
             debug.println(debug.LEVEL_SEVERE,
-                           "orca.setLocusOfFocus() application LookupError")
+                           "orca.setLocusOfFocus() application Error")
         if not currentApp in appList:
             return
 
@@ -972,7 +972,7 @@ def keyEcho(event):
     #
     try:
         role = orca_state.locusOfFocus.getRole()
-    except LookupError:
+    except (LookupError, RuntimeError):
         debug.println(debug.LEVEL_SEVERE,
                       "orca.keyEcho() - locusOfFocus no longer exists")
         setLocusOfFocus(None, None, False)
@@ -1460,7 +1460,7 @@ def _restoreXmodmap(keyList=[]):
 
     os.system("echo '%s' | xmodmap - > /dev/null 2>&1" % "\n".join(toRestore))
 
-def loadUserSettings(script=None, inputEvent=None, isProfileLoad=False):
+def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
     """Loads (and reloads) the user settings module, reinitializing
     things such as speech if necessary.
 
@@ -1517,7 +1517,7 @@ def loadUserSettings(script=None, inputEvent=None, isProfileLoad=False):
     if settings.enableSpeech:
         try:
             speech.init()
-            if reloaded and not isProfileLoad:
+            if reloaded and not skipReloadMessage:
                 # Translators: there is a keystroke to reload the user
                 # preferences.  This is a spoken prompt to let the user
                 # know when the preferences has been reloaded.
@@ -1573,11 +1573,11 @@ def loadUserSettings(script=None, inputEvent=None, isProfileLoad=False):
     _storeXmodmap(_orcaModifiers)
     _createOrcaXmodmap()
 
+    showMainWindowGUI()
+
     _scriptManager.activate()
     _eventManager.activate()
 
-    showMainWindowGUI()
-
     # Only start the D-Bus server if we're in an environment where there 
     # is a D-Bus session bus already running.  This helps prevent nastiness
     # on the login screen.
@@ -2312,6 +2312,9 @@ def main():
         else:
             _showPreferencesConsole()
         _settingsManager.setFirstStart()
+    elif options.bypassSetup:
+        loadUserSettings(skipReloadMessage=True)
+        _settingsManager.setFirstStart()
 
     try:
         start(pyatspi.Registry) # waits until we stop the registry
