@@ -487,6 +487,7 @@ class SettingsManager(object):
         """
 
         self._loadProfileSettings()
+        script.voices = self.getSetting('voices')
 
         import orca
         _scriptManager = getattr(orca, '_scriptManager')
@@ -521,6 +522,10 @@ class SettingsManager(object):
         self._knownAppSettings[name] = module
         reload(self._knownAppSettings[name])
 
+        appVoices = self.getSetting('voices')
+        for voiceType, voiceDef in appVoices.items():
+            script.voices[voiceType].update(voiceDef)
+
         keybindings = getattr(module, 'overrideAppKeyBindings', None)
         if keybindings:
             script.overrideAppKeyBindings = keybindings
